@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -210,7 +210,8 @@ MOS_STATUS CodecHalGetKernelBinaryAndSize(
     uint8_t**  kernelBinary,
     uint32_t*  size)
 {
-#ifndef _FULL_OPEN_SOURCE
+#ifdef ENABLE_KERNELS
+
     CODECHAL_PUBLIC_CHK_NULL_RETURN(kernelBase);
     CODECHAL_PUBLIC_CHK_NULL_RETURN(kernelBinary);
     CODECHAL_PUBLIC_CHK_NULL_RETURN(size);
@@ -365,6 +366,15 @@ MOS_STATUS CodecHalSetRcsSurfaceState(
         surfaceRcsParams.dwHeightToUse[MHW_Y_PLANE]           = (surfaceCodecParams->dwHeightInUse == 0) ?
             ((surfaceCodecParams->bUseHalfHeight) ? (surfaceCodecParams->psSurface->dwHeight / 2) : surfaceCodecParams->psSurface->dwHeight)
             : surfaceCodecParams->dwHeightInUse;
+
+        if (surfaceCodecParams->bCheckCSC8Format &&
+            (surfaceCodecParams->psSurface->Format == Format_AYUV || surfaceCodecParams->psSurface->Format == Format_Y410 ||
+            surfaceCodecParams->psSurface->Format == Format_R10G10B10A2 || surfaceCodecParams->psSurface->Format == Format_B10G10R10A2))
+        {
+            surfaceRcsParams.ForceSurfaceFormat[MHW_Y_PLANE] = MHW_GFX3DSTATE_SURFACEFORMAT_R8_UNORM;
+            surfaceRcsParams.dwWidthToUse[MHW_Y_PLANE] = surfaceRcsParams.dwWidthToUse[MHW_Y_PLANE] * 4;
+        }
+
         surfaceRcsParams.dwBindingTableOffset[MHW_Y_PLANE]    = surfaceCodecParams->dwBindingTableOffset;
         surfaceRcsParams.dwYOffset[MHW_Y_PLANE]               = surfaceCodecParams->psSurface->YPlaneOffset.iYOffset;
         surfaceRcsParams.bVertLineStride                      = surfaceCodecParams->dwVerticalLineStride;
@@ -513,6 +523,8 @@ MOS_STATUS CodecHalGetResourceInfo(
     surface->dwQPitch      = details.dwQPitch;
     surface->bArraySpacing = details.bArraySpacing;
     surface->TileType      = details.TileType;
+    surface->TileModeGMM   = details.TileModeGMM;
+    surface->bGMMTileEnabled = details.bGMMTileEnabled;
     surface->dwOffset      = details.RenderOffset.YUV.Y.BaseOffset;
     surface->YPlaneOffset.iSurfaceOffset = details.RenderOffset.YUV.Y.BaseOffset;
     surface->YPlaneOffset.iXOffset = details.RenderOffset.YUV.Y.XOffset;
